@@ -10,9 +10,15 @@ use crate::money::Money;
 use crate::shipping::FulfillmentType;
 
 #[derive(Clone, Serialize, Deserialize, JsonSchema)]
-pub enum Tax {
-    Percentage(String, Decimal),
-    Absolute(String, Money),
+pub enum TaxValue {
+    Percentage(Decimal),
+    Absolute(Money),
+}
+
+#[derive(Clone, Serialize, Deserialize, JsonSchema)]
+pub struct Tax {
+    pub title: String,
+    pub value: TaxValue,
 }
 
 #[derive(Clone, Serialize, Deserialize, JsonSchema)]
@@ -108,18 +114,22 @@ pub trait InvoiceCalculator {
         let total_line_item_taxes =
             line_item_taxes
                 .iter()
-                .fold(Money::new(co.currency.clone(), "0"), |t, tax| match tax {
-                    Tax::Absolute(_, amount) => t.add(amount),
-                    Tax::Percentage(_, rate) => t.add(&subtotal.mul(rate)),
+                .fold(Money::new(co.currency.clone(), "0"), |t, tax| {
+                    match &tax.value {
+                        TaxValue::Absolute(amount) => t.add(amount),
+                        TaxValue::Percentage(rate) => t.add(&subtotal.mul(rate)),
+                    }
                 });
 
         let shipping_taxes = self.shipping_taxes(co).await?;
         let total_shipping_taxes =
             shipping_taxes
                 .iter()
-                .fold(Money::new(co.currency.clone(), "0"), |t, tax| match tax {
-                    Tax::Absolute(_, amount) => t.add(amount),
-                    Tax::Percentage(_, rate) => t.add(&shipping_total.mul(rate)),
+                .fold(Money::new(co.currency.clone(), "0"), |t, tax| {
+                    match &tax.value {
+                        TaxValue::Absolute(amount) => t.add(amount),
+                        TaxValue::Percentage(rate) => t.add(&shipping_total.mul(rate)),
+                    }
                 });
 
         let total_taxes = total_line_item_taxes.add(&total_shipping_taxes);
